# ActivityResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**activity_reference_number** | **str** |  | 
**usrn** | **float** |  | 
**street_name** | **str** |  | [optional] 
**town** | **str** |  | [optional] 
**area_name** | **str** |  | [optional] 
**road_category** | **float** |  | [optional] 
**activity_coordinates** | **object** |  | 
**activity_name** | **str** |  | 
**activity_activity_type** | [**ActivityActivityTypeResponse**](ActivityActivityTypeResponse.md) |  | 
**activity_activity_type_string** | **str** |  | 
**activity_type_details** | **str** |  | [optional] 
**contact_name** | **str** |  | [optional] 
**contact_details** | **str** |  | [optional] 
**start_date** | **datetime** |  | 
**start_time** | **datetime** |  | [optional] 
**end_date** | **datetime** |  | 
**end_time** | **datetime** |  | [optional] 
**location_types** | [**list[LocationTypeResponse]**](LocationTypeResponse.md) |  | 
**location_types_string** | **list[str]** |  | 
**activity_location_description** | **str** |  | 
**traffic_management_type** | [**TrafficManagementTypeResponse**](TrafficManagementTypeResponse.md) |  | 
**traffic_management_type_string** | **str** |  | 
**collaborative_working** | **bool** |  | 
**additional_info** | **str** |  | [optional] 
**cancelled** | **bool** |  | 
**cancelled_reason** | **str** |  | [optional] 
**highway_authority_swa_code** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

